@@ -321,7 +321,7 @@ ShapeAlgorithms.getIntersectingShapes = function(doc, entityId, shape, extend) {
 
     // find other shapes that potentially intersect with the chosen entity:
     var ret = [];
-    // allow for error: especialy for ellipse segments bordering to tangential lines this is needed:
+    // allow for error: especially for ellipse segments bordering to tangential lines this is needed:
     var otherEntityIds;
 
     if (extend===true) {
@@ -798,6 +798,8 @@ ShapeAlgorithms.autoSplitManual = function(shape, cutDist1, cutDist2, cutPos1, c
 
     // polyline:
     else if (isPolylineShape(shape)) {
+        // TODO: make sure point 1 is closer to the start of the polyline:
+
         var closed = shape.isGeometricallyClosed();
         if (closed) {
             shape.relocateStartPoint(cutDist1);
@@ -1830,17 +1832,20 @@ ShapeAlgorithms.transformArc = function(arc, fun) {
         r2 = new RVector(0, arc.getRadius());
     }
 
+    // get vertices at extremities:
     var v1 = arc.getCenter().operator_add(r1).operator_add(r2);
     var v2 = arc.getCenter().operator_add(r1).operator_subtract(r2);
     var v3 = arc.getCenter().operator_subtract(r1).operator_subtract(r2);
     var v4 = arc.getCenter().operator_subtract(r1).operator_add(r2);
 
+    // project those vertices:
     fun(v1);
     fun(v2);
     fun(v3);
     fun(v4);
 
     //var ret = [];
+    // inscribe ellipse into vertices:
     var ellipse = ShapeAlgorithms.createEllipseInscribedFromVertices(v1, v2, v3, v4);
     //ret.push(ellipse.copy());
 
@@ -2013,7 +2018,13 @@ ShapeAlgorithms.divideShape = function(shape, pos1, pos2) {
 
         shape1 = trimEndPoint(shape1, pos1, pos1);
 
-        cutPos1 = shape1.getEndPoint();
+        if (isRayShape(shape1)) {
+            // ray points in opposite direction:
+            cutPos1 = shape1.getStartPoint();
+        }
+        else {
+            cutPos1 = shape1.getEndPoint();
+        }
 
         shape2 = trimStartPoint(shape2, pos1, pos1);
 
